"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var IconButton_1 = require("@material-ui/core/IconButton/IconButton");
var InputAdornment_1 = require("@material-ui/core/InputAdornment/InputAdornment");
var MenuItem_1 = require("@material-ui/core/MenuItem/MenuItem");
var Close_1 = require("@material-ui/icons/Close");
var Search_1 = require("@material-ui/icons/Search");
var FieldCoreBase_1 = require("@react-form-fields/core/components/FieldCoreBase");
var ValidationContextRegister_1 = require("@react-form-fields/core/components/ValidationContextRegister");
var match = require("autosuggest-highlight/match");
var parse = require("autosuggest-highlight/parse");
var React = require("react");
var Autosuggest = require("react-autosuggest");
var config_1 = require("../../config");
var withStyles_1 = require("../../decorators/withStyles");
var Input_1 = require("./Input");
var SuggestionsContainer_1 = require("./SuggestionsContainer");
var FieldAutocomplete = /** @class */ (function (_super) {
    tslib_1.__extends(FieldAutocomplete, _super);
    function FieldAutocomplete(props) {
        var _this = _super.call(this, props) || this;
        _this.onChange = function (value) {
            config_1.getConfig().validationOn === 'onChange' && _this.setState({ showError: true });
            _this.props.onChange(value);
        };
        _this.getSuggestionValue = function (suggestion) {
            return suggestion.label;
        };
        _this.handleChange = function (event, params) {
            _this.setState({ term: params.newValue });
        };
        _this.handleBlur = function () {
            var _a = _this.props, value = _a.value, options = _a.options;
            config_1.getConfig().validationOn === 'onBlur' && _this.setState({ showError: true });
            if (!_this.state.term) {
                return _this.handleClearValue();
            }
            var term = (options.find(function (o) { return o.value === value; }) || { label: null }).label;
            _this.setState({ term: term });
        };
        _this.handleSelected = function (event, data) {
            _this.onChange(data.suggestion.value);
        };
        _this.handleSuggestionsFetchRequested = function (_a) {
            var value = _a.value;
            var suggestions = _this.props.options
                .filter(function (o) { return o.label.toString().toLowerCase().includes(value.toLowerCase()); })
                .slice(0, 10);
            _this.setState({ suggestions: suggestions });
        };
        _this.handleSuggestionsClearRequested = function () {
            _this.setState({ suggestions: [] });
        };
        _this.handleClearValue = function () {
            _this.setState({ term: null });
            _this.onChange(null);
        };
        _this.shouldRenderSuggestions = function () { return true; };
        _this.state = tslib_1.__assign({}, _this.state, { term: '', suggestions: [] });
        return _this;
    }
    FieldAutocomplete.getDerivedStateFromProps = function (nextProps, currentState) {
        var term = currentState.term;
        if (nextProps.value !== currentState.value || term === undefined) {
            term = (nextProps.options.find(function (o) { return o.value === nextProps.value; }) || { label: undefined }).label;
        }
        return tslib_1.__assign({}, currentState, FieldCoreBase_1.default.getDerivedStateFromProps(nextProps, currentState), { value: nextProps.value, term: term });
    };
    FieldAutocomplete.prototype.render = function () {
        var _a = this.state, term = _a.term, suggestions = _a.suggestions;
        var _b = this.props, classes = _b.classes, placeholder = _b.placeholder, disabled = _b.disabled, label = _b.label;
        return (React.createElement(React.Fragment, null,
            React.createElement(ValidationContextRegister_1.default, { field: this }),
            React.createElement(Autosuggest, { suggestions: suggestions, theme: {
                    container: classes.container,
                    suggestionsContainerOpen: classes.suggestionsContainerOpen + " " + (label ? classes.suggestionsContainerOpenWithLabel : ''),
                    suggestionsList: classes.suggestionsList,
                    suggestion: classes.suggestion,
                }, renderInputComponent: Input_1.default, renderSuggestionsContainer: SuggestionsContainer_1.default, shouldRenderSuggestions: this.shouldRenderSuggestions, onSuggestionsFetchRequested: this.handleSuggestionsFetchRequested, onSuggestionsClearRequested: this.handleSuggestionsClearRequested, getSuggestionValue: this.getSuggestionValue, renderSuggestion: this.renderSuggestion, onSuggestionSelected: this.handleSelected, inputProps: tslib_1.__assign({}, this.props, { errorMessage: this.errorMessage, classes: classes, placeholder: placeholder || 'Pesquisar...', required: this.isRequired, value: term || '', onBlur: this.handleBlur, onChange: this.handleChange, endAdornment: (!term ?
                        React.createElement(InputAdornment_1.default, { position: 'end' },
                            React.createElement(IconButton_1.default, { disabled: true, className: classes.adornment },
                                React.createElement(Search_1.default, null)))
                        :
                            React.createElement(InputAdornment_1.default, { position: 'end', onClick: this.handleClearValue },
                                React.createElement(IconButton_1.default, { disabled: disabled, className: classes.adornment },
                                    React.createElement(Close_1.default, null)))) }) })));
    };
    FieldAutocomplete.prototype.renderSuggestion = function (suggestion, _a) {
        var query = _a.query, isHighlighted = _a.isHighlighted;
        var matches = match(suggestion.label, query);
        var parts = parse(suggestion.label, matches);
        return (React.createElement(MenuItem_1.default, { selected: isHighlighted, component: 'div' },
            React.createElement("div", null, parts.map(function (part, index) {
                return part.highlight ? (React.createElement("span", { key: index, style: { fontWeight: 300 } }, part.text)) : (React.createElement("strong", { key: index, style: { fontWeight: 500 } }, part.text));
            }))));
    };
    FieldAutocomplete = tslib_1.__decorate([
        withStyles_1.WithStyles(function (theme) { return ({
            container: {
                position: 'relative'
            },
            suggestionsContainerOpen: {
                position: 'absolute',
                zIndex: 1,
                left: 0,
                right: 0,
                top: 50
            },
            suggestionsContainerOpenWithLabel: {
                top: 65
            },
            suggestion: {
                display: 'block',
            },
            suggestionsList: {
                margin: 0,
                padding: 0,
                listStyleType: 'none',
            },
            adornment: {
                marginRight: -15
            }
        }); })
    ], FieldAutocomplete);
    return FieldAutocomplete;
}(FieldCoreBase_1.default));
exports.default = FieldAutocomplete;
//# sourceMappingURL=index.js.map